@@ -105,7 +105,7 @@ class Account(Base):
 
     # Родительская учетная запись
     parent_account_id = Column(ForeignKey('accounts.id'))
-    parent_account = relationship('Account')
+    parent_account = relationship('Account', foreign_keys=[parent_account_id])
 
     # SIS-идентификатор
     sis_source_id = Column(String(255))
@@ -118,7 +118,7 @@ class Account(Base):
 
     # Корневая учетная запись
     root_account_id = Column(ForeignKey('accounts.id'))
-    root_account = relationship('Account')
+    root_account = relationship('Account', foreign_keys=[root_account_id])
 
     # Неизвестное поле
     last_successful_sis_batch_id = Column(Integer)
@@ -221,21 +221,39 @@ class Account(Base):
 
 class Wiki(Base):
     """
-    Модель "Wiki"
+    Wiki
     """
     __tablename__ = 'wikis'
 
     # Идентификатор
     id = Column(Integer, primary_key=True)
 
-    # Заголовок
+    # Наименование
     title = Column(String(255))
 
+    # Дата и время создания
+    # server_default - Автоматически устанавливает значение created_at на текущую дату и время при создании
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Дата и время изменения
+    # onupdate - Автоматически изменяет updated_at на текущую дату и время
+    updated_at = Column(DateTime, onupdate=func.now())
+
+    # Неизвестное поле
+    front_page_url = Column(String)
+
+    # Неизвестное поле
+    has_no_front_page = Column(Boolean)
+
+    # Корневая учетная запись
+    root_account_id = Column(ForeignKey('accounts.id'))
+    root_account = relationship('Account')
+
     def __repr__(self):
-        return '<Wiki {} (id={})>'.format(self, self.id)
+        return f'<Wiki {self} (id={self.id})>'
 
     def __str__(self):
-        return self.title
+        return f'{self.title}'
 
 
 class EnrollmentTerm(Base):
